﻿# Script to fix individual MySite when migrating to new domain
# Assuming user has same name in new domain
# To work:
# Modify $siteToFix, $oldDomain, $newDomain to fit your environment
#
# // Jonas Widriksson, 2016

$siteToFix = "http://mysites.dev.local/personal/administrator"
$oldDomain = "Old_Domain_Name"
$newDomain = "New_Domain_Name"

Add-PSSnapin "Microsoft.SharePoint.PowerShell"

#Instantiate Web Application Object
$webApplication = Get-SPWebApplication -Identity $siteToFix
    
#Create Service Context for User Profile Manager
$context = Get-SPServiceContext $webApplication.Sites[0]
 
#Get User Profile Manager instance
$profileManager = new-object Microsoft.Office.Server.UserProfiles.UserProfileManager($context)


[Microsoft.SharePoint.SPSecurity]::RunWithElevatedPrivileges({

    #Iterate through site collection in My Site Host web application
    $siteCol = Get-SPSite -Identity $siteToFix
    
	try{
		Write-Host "Start site: " $siteCol.Url -ForegroundColor Cyan
		Write-Host "Site owner: " $siteCol.Owner.LoginName -ForegroundColor Gray 

        if ($siteCol.Owner.Login -ilike "$oldDomain*") {
            Write-Host "Site owner not new domain... fixing... " $siteCol.Owner.LoginName -ForegroundColor Green
            $newLogin = ($siteCol.Owner -ireplace $oldDomain, $newDomain)
            Set-SPSite -Identity $siteToFix -OwnerAlias $newLogin
        }

        if ($siteCol.CompatibilityLevel -eq '14') {
            Write-Host "Upgrading site..." -ForegroundColor Green
            upgrade-spsite $siteCol.Url -versionupgrade
            Write-Host "Upgrade complete!" -ForegroundColor Green
        }
   
	    $uProfile = $profileManager.GetUserProfile($siteCol.Owner.LoginName -ireplace "$newDomain\\", "")
	
        if ($uProfile) {
            Write-Host "Found userprofile: " $uProfile.DisplayName -ForegroundColor Gray
		    Write-Host "User personal site: " $uProfile.PersonalSite.ServerRelativeUrl -ForegroundColor Gray

            Write-Host -ForegroundColor Green "Change new mysite to: " $siteCol.RootWeb.ServerRelativeUrl
             
            $uProfile["PersonalSpace"].Value = $siteCol.RootWeb.ServerRelativeUrl
            $updateProfile = $true
                
        # Check so that site is activated
        if ($uProfile["SPS-PersonalSiteCapabilities"].Value -eq $null -or $uProfile["SPS-PersonalSiteCapabilities"].Value -eq 0) {
            
            Write-Host -ForegroundColor Red "Personal Site has no capabilities"
            Write-Host -ForegroundColor Green "Updating capabilities" $siteCol.RootWeb.ServerRelativeUrl

            $uProfile["SPS-PersonalSiteCapabilities"].Value = 13
            $updateProfile = $true
        }

        # Check so that site is not marked as deleted
        if ($uProfile["SPS-PersonalSiteInstantiationState"].Value -eq $null -or $uProfile["SPS-PersonalSiteInstantiationState"].Value -eq 0 -or $uProfile["SPS-PersonalSiteInstantiationState"].Value -eq 3) {

            Write-Host -ForegroundColor Red "Site marked as deleted or not created"
            Write-Host -ForegroundColor Green "Updating site as created" $siteCol.RootWeb.ServerRelativeUrl

            $uProfile["SPS-PersonalSiteInstantiationState"].Value = 2
            $updateProfile = $true
        }         

          if ($updateProfile) {
            Write-Host "Commit changes to UPS..." -ForegroundColor Green
            $uProfile.Commit()
        }

        }
        else {
            Write-Host "No Profile found!" -ForegroundColor Red
        }
        Write-Host "End..." -ForegroundColor Cyan

}
    catch{
        Write-Host "Error: " $_ -ForegroundColor Red
		$ownerLoginName = $siteCol.Owner.LoginName
		Add-Content .\UpdateMySiteUserProfilesLinkErrorNew.txt "User: $ownerLoginName $_"
	} 
     
})


   
   
   
       